@@ -1,3 +1,5 @@
+package org.codehaus.plexus.util;
+
 /*
  * The Apache Software License, Version 1.1
  *
@@ -17,11 +19,11 @@
  *    distribution.
  *
  * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
+ *    any, must include the following acknowledgement:
  *       "This product includes software developed by the
  *        Apache Software Foundation (http://www.codehaus.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
+ *    Alternately, this acknowledgement may appear in the software itself,
+ *    if and wherever such third-party acknowledgements normally appear.
  *
  * 4. The names "Ant" and "Apache Software
  *    Foundation" must not be used to endorse or promote products derived
@@ -52,97 +54,79 @@
  * <http://www.codehaus.org/>.
  */
 
-package org.codehaus.plexus.util;
-
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Vector;
 
 /**
- * Class for scanning a directory for files/directories which match certain
- * criteria.
- * <p/>
- * These criteria consist of selectors and patterns which have been specified.
- * With the selectors you can select which files you want to have included.
- * Files which are not selected are excluded. With patterns you can include
- * or exclude files based on their filename.
- * <p/>
- * The idea is simple. A given directory is recursively scanned for all files
- * and directories. Each file/directory is matched against a set of selectors,
- * including special support for matching against filenames with include and
- * and exclude patterns. Only files/directories which match at least one
- * pattern of the include pattern list or other file selector, and don't match
- * any pattern of the exclude pattern list or fail to match against a required
- * selector will be placed in the list of files/directories found.
- * <p/>
- * When no list of include patterns is supplied, "**" will be used, which
- * means that everything will be matched. When no list of exclude patterns is
- * supplied, an empty list is used, such that nothing will be excluded. When
- * no selectors are supplied, none are applied.
- * <p/>
- * The filename pattern matching is done as follows:
- * The name to be matched is split up in path segments. A path segment is the
- * name of a directory or file, which is bounded by
- * <code>File.separator</code> ('/' under UNIX, '\' under Windows).
- * For example, "abc/def/ghi/xyz.java" is split up in the segments "abc",
- * "def","ghi" and "xyz.java".
- * The same is done for the pattern against which should be matched.
- * <p/>
- * The segments of the name and the pattern are then matched against each
- * other. When '**' is used for a path segment in the pattern, it matches
- * zero or more path segments of the name.
- * <p/>
- * There is a special case regarding the use of <code>File.separator</code>s
- * at the beginning of the pattern and the string to match:<br>
- * When a pattern starts with a <code>File.separator</code>, the string
- * to match must also start with a <code>File.separator</code>.
- * When a pattern does not start with a <code>File.separator</code>, the
- * string to match may not start with a <code>File.separator</code>.
- * When one of these rules is not obeyed, the string will not
- * match.
- * <p/>
- * When a name path segment is matched against a pattern path segment, the
- * following special characters can be used:<br>
+ * <p>Class for scanning a directory for files/directories which match certain criteria.</p>
+ * 
+ * <p>These criteria consist of selectors and patterns which have been specified. With the selectors you can select which
+ * files you want to have included. Files which are not selected are excluded. With patterns you can include or exclude
+ * files based on their filename.</p>
+ * 
+ * <p>The idea is simple. A given directory is recursively scanned for all files and directories. Each file/directory is
+ * matched against a set of selectors, including special support for matching against filenames with include and and
+ * exclude patterns. Only files/directories which match at least one pattern of the include pattern list or other file
+ * selector, and don't match any pattern of the exclude pattern list or fail to match against a required selector will
+ * be placed in the list of files/directories found.</p>
+ * 
+ * <p>When no list of include patterns is supplied, "**" will be used, which means that everything will be matched. When no
+ * list of exclude patterns is supplied, an empty list is used, such that nothing will be excluded. When no selectors
+ * are supplied, none are applied.</p>
+ * 
+ * <p>The filename pattern matching is done as follows: The name to be matched is split up in path segments. A path segment
+ * is the name of a directory or file, which is bounded by <code>File.separator</code> ('/' under UNIX, '\' under
+ * Windows). For example, "abc/def/ghi/xyz.java" is split up in the segments "abc", "def","ghi" and "xyz.java". The same
+ * is done for the pattern against which should be matched.</p>
+ * 
+ * <p>The segments of the name and the pattern are then matched against each other. When '**' is used for a path segment in
+ * the pattern, it matches zero or more path segments of the name.</p>
+ * 
+ * <p>There is a special case regarding the use of <code>File.separator</code>s at the beginning of the pattern and the
+ * string to match:<br>
+ * When a pattern starts with a <code>File.separator</code>, the string to match must also start with a
+ * <code>File.separator</code>. When a pattern does not start with a <code>File.separator</code>, the string to match
+ * may not start with a <code>File.separator</code>. When one of these rules is not obeyed, the string will not match.</p>
+ * 
+ * <p>When a name path segment is matched against a pattern path segment, the following special characters can be used:<br>
  * '*' matches zero or more characters<br>
- * '?' matches one character.
- * <p/>
+ * '?' matches one character.</p>
+ * 
  * Examples:
- * <p/>
- * "**\*.class" matches all .class files/dirs in a directory tree.
- * <p/>
- * "test\a??.java" matches all files/dirs which start with an 'a', then two
- * more characters and then ".java", in a directory called test.
- * <p/>
- * "**" matches everything in a directory tree.
- * <p/>
- * "**\test\**\XYZ*" matches all files/dirs which start with "XYZ" and where
- * there is a parent directory called test (e.g. "abc\test\def\ghi\XYZ123").
- * <p/>
- * Case sensitivity may be turned off if necessary. By default, it is
- * turned on.
- * <p/>
+ * <ul>
+ *   <li>"**\*.class" matches all .class files/dirs in a directory tree.</li>
+ *   <li>"test\a??.java" matches all files/dirs which start with an 'a', then two more characters and then ".java", in a
+ * directory called test.</li>
+ *   <li>"**" matches everything in a directory tree.</li>
+ *   <li>"**\test\**\XYZ*" matches all files/dirs which start with "XYZ" and where there is a parent directory called test
+ * (e.g. "abc\test\def\ghi\XYZ123").</li>
+ * </ul>
+ * 
+ * <p>Case sensitivity may be turned off if necessary. By default, it is turned on.</p>
  * Example of usage:
  * <pre>
- *   String[] includes = {"**\\*.class"};
- *   String[] excludes = {"modules\\*\\**"};
- *   ds.setIncludes(includes);
- *   ds.setExcludes(excludes);
- *   ds.setBasedir(new File("test"));
- *   ds.setCaseSensitive(true);
- *   ds.scan();
+ * String[] includes = { "**\\*.class" };
+ * String[] excludes = { "modules\\*\\**" };
+ * ds.setIncludes( includes );
+ * ds.setExcludes( excludes );
+ * ds.setBasedir( new File( "test" ) );
+ * ds.setCaseSensitive( true );
+ * ds.scan();
  *
- *   System.out.println("FILES:");
- *   String[] files = ds.getIncludedFiles();
- *   for (int i = 0; i < files.length; i++) {
- *     System.out.println(files[i]);
- *   }
+ * System.out.println( "FILES:" );
+ * String[] files = ds.getIncludedFiles();
+ * for ( int i = 0; i &lt; files.length; i++ )
+ * {
+ *     System.out.println( files[i] );
+ * }
  * </pre>
- * This will scan a directory called test for .class files, but excludes all
- * files in all proper subdirectories of a directory called "modules"
+ * 
+ * <p>This will scan a directory called test for .class files, but excludes all files in all proper subdirectories of a
+ * directory called "modules"</p>
  *
- * @author Arnout J. Kuiper
- *         <a href="mailto:ajkuiper@wxs.nl">ajkuiper@wxs.nl</a>
+ * @author Arnout J. Kuiper <a href="mailto:ajkuiper@wxs.nl">ajkuiper@wxs.nl</a>
  * @author Magesh Umasankar
  * @author <a href="mailto:bruce@callenish.com">Bruce Atherton</a>
  * @author <a href="mailto:levylambert@tiscali-dsl.de">Antoine Levy-Lambert</a>
@@ -157,8 +141,7 @@ public class DirectoryScanner
     protected File basedir;
 
     /**
-     * The files which matched at least one include and no excludes
-     * and were selected.
+     * The files which matched at least one include and no excludes and were selected.
      */
     protected Vector<String> filesIncluded;
 
@@ -168,14 +151,12 @@ public class DirectoryScanner
     protected Vector<String> filesNotIncluded;
 
     /**
-     * The files which matched at least one include and at least
-     * one exclude.
+     * The files which matched at least one include and at least one exclude.
      */
     protected Vector<String> filesExcluded;
 
     /**
-     * The directories which matched at least one include and no excludes
-     * and were selected.
+     * The directories which matched at least one include and no excludes and were selected.
      */
     protected Vector<String> dirsIncluded;
 
@@ -185,20 +166,17 @@ public class DirectoryScanner
     protected Vector<String> dirsNotIncluded;
 
     /**
-     * The directories which matched at least one include and at least one
-     * exclude.
+     * The directories which matched at least one include and at least one exclude.
      */
     protected Vector<String> dirsExcluded;
 
     /**
-     * The files which matched at least one include and no excludes and
-     * which a selector discarded.
+     * The files which matched at least one include and no excludes and which a selector discarded.
      */
     protected Vector<String> filesDeselected;
 
     /**
-     * The directories which matched at least one include and no excludes
-     * but which a selector discarded.
+     * The directories which matched at least one include and no excludes but which a selector discarded.
      */
     protected Vector<String> dirsDeselected;
 
@@ -229,13 +207,11 @@ public class DirectoryScanner
     }
 
     /**
-     * Sets the base directory to be scanned. This is the directory which is
-     * scanned recursively. All '/' and '\' characters are replaced by
-     * <code>File.separatorChar</code>, so the separator used need not match
+     * Sets the base directory to be scanned. This is the directory which is scanned recursively. All '/' and '\'
+     * characters are replaced by <code>File.separatorChar</code>, so the separator used need not match
      * <code>File.separatorChar</code>.
      *
-     * @param basedir The base directory to scan.
-     *                Must not be <code>null</code>.
+     * @param basedir The base directory to scan. Must not be <code>null</code>.
      */
     public void setBasedir( String basedir )
     {
@@ -243,11 +219,9 @@ public class DirectoryScanner
     }
 
     /**
-     * Sets the base directory to be scanned. This is the directory which is
-     * scanned recursively.
+     * Sets the base directory to be scanned. This is the directory which is scanned recursively.
      *
-     * @param basedir The base directory for scanning.
-     *                Should not be <code>null</code>.
+     * @param basedir The base directory for scanning. Should not be <code>null</code>.
      */
     public void setBasedir( File basedir )
     {
@@ -255,8 +229,7 @@ public class DirectoryScanner
     }
 
     /**
-     * Returns the base directory to be scanned.
-     * This is the directory which is scanned recursively.
+     * Returns the base directory to be scanned. This is the directory which is scanned recursively.
      *
      * @return the base directory to be scanned
      */
@@ -276,11 +249,9 @@ public class DirectoryScanner
     }
 
     /**
-     * Returns whether or not the scanner has included all the files or
-     * directories it has come across so far.
+     * Returns whether or not the scanner has included all the files or directories it has come across so far.
      *
-     * @return <code>true</code> if all files and directories which have
-     *         been found so far have been included.
+     * @return <code>true</code> if all files and directories which have been found so far have been included.
      */
     public boolean isEverythingIncluded()
     {
@@ -288,13 +259,11 @@ public class DirectoryScanner
     }
 
     /**
-     * Scans the base directory for files which match at least one include
-     * pattern and don't match any exclude patterns. If there are selectors
-     * then the files must pass muster there, as well.
+     * Scans the base directory for files which match at least one include pattern and don't match any exclude patterns.
+     * If there are selectors then the files must pass muster there, as well.
      *
-     * @throws IllegalStateException if the base directory was set
-     *                               incorrectly (i.e. if it is <code>null</code>, doesn't exist,
-     *                               or isn't a directory).
+     * @throws IllegalStateException if the base directory was set incorrectly (i.e. if it is <code>null</code>, doesn't
+     *             exist, or isn't a directory).
      */
     public void scan()
         throws IllegalStateException
@@ -351,12 +320,11 @@ public class DirectoryScanner
     }
 
     /**
-     * Top level invocation for a slow scan. A slow scan builds up a full
-     * list of excluded/included files/directories, whereas a fast scan
-     * will only have full results for included files, as it ignores
-     * directories which can't possibly hold any included files/directories.
-     * <p/>
-     * Returns immediately if a slow scan has already been completed.
+     * <p>Top level invocation for a slow scan. A slow scan builds up a full list of excluded/included files/directories,
+     * whereas a fast scan will only have full results for included files, as it ignores directories which can't
+     * possibly hold any included files/directories.</p>
+     * 
+     * <p>Returns immediately if a slow scan has already been completed.</p>
      */
     protected void slowScan()
     {
@@ -391,16 +359,14 @@ public class DirectoryScanner
     }
 
     /**
-     * Scans the given directory for files and directories. Found files and
-     * directories are placed in their respective collections, based on the
-     * matching of includes, excludes, and the selectors.  When a directory
-     * is found, it is scanned recursively.
+     * Scans the given directory for files and directories. Found files and directories are placed in their respective
+     * collections, based on the matching of includes, excludes, and the selectors. When a directory is found, it is
+     * scanned recursively.
      *
-     * @param dir   The directory to scan. Must not be <code>null</code>.
-     * @param vpath The path relative to the base directory (needed to
-     *              prevent problems with an absolute path when using
-     *              dir). Must not be <code>null</code>.
-     * @param fast  Whether or not this call is part of a fast scan.
+     * @param dir The directory to scan. Must not be <code>null</code>.
+     * @param vpath The path relative to the base directory (needed to prevent problems with an absolute path when using
+     *            dir). Must not be <code>null</code>.
+     * @param fast Whether or not this call is part of a fast scan.
      * @see #filesIncluded
      * @see #filesNotIncluded
      * @see #filesExcluded
@@ -416,21 +382,15 @@ public class DirectoryScanner
         if ( newfiles == null )
         {
             /*
-             * two reasons are mentioned in the API docs for File.list
-             * (1) dir is not a directory. This is impossible as
-             *     we wouldn't get here in this case.
-             * (2) an IO error occurred (why doesn't it throw an exception
-             *     then???)
+             * two reasons are mentioned in the API docs for File.list (1) dir is not a directory. This is impossible as
+             * we wouldn't get here in this case. (2) an IO error occurred (why doesn't it throw an exception then???)
              */
 
             /*
-            * [jdcasey] (2) is apparently happening to me, as this is killing one of my tests...
-            * this is affecting the assembly plugin, fwiw. I will initialize the newfiles array as
-            * zero-length for now.
-            *
-            * NOTE: I can't find the problematic code, as it appears to come from a native method
-            * in UnixFileSystem...
-            */
+             * [jdcasey] (2) is apparently happening to me, as this is killing one of my tests... this is affecting the
+             * assembly plugin, fwiw. I will initialize the newfiles array as zero-length for now. NOTE: I can't find
+             * the problematic code, as it appears to come from a native method in UnixFileSystem...
+             */
             /*
              * [bentmann] A null array will also be returned from list() on NTFS when dir refers to a soft link or
              * junction point whose target is not existent.
@@ -467,19 +427,19 @@ public class DirectoryScanner
                 }
                 catch ( IOException ioe )
                 {
-                    String msg = "IOException caught while checking " + "for links, couldn't get cannonical path!";
+                    String msg = "IOException caught while checking " + "for links, couldn't get canonical path!";
                     // will be caught and redirected to Ant's logging system
                     System.err.println( msg );
                     noLinks.add( newfile );
                 }
             }
-            newfiles = noLinks.toArray(new String[noLinks.size()]);
+            newfiles = noLinks.toArray( new String[noLinks.size()] );
         }
 
         for ( String newfile : newfiles )
         {
             String name = vpath + newfile;
-            String[] tokenizedName =  MatchPattern.tokenizePathToString( name, File.separator );
+            String[] tokenizedName = MatchPattern.tokenizePathToString( name, File.separator );
             File file = new File( dir, newfile );
             if ( file.isDirectory() )
             {
@@ -567,8 +527,8 @@ public class DirectoryScanner
      *
      * @param name the filename to check for selecting
      * @param file the java.io.File object for this filename
-     * @return <code>false</code> when the selectors says that the file
-     *         should not be selected, <code>true</code> otherwise.
+     * @return <code>false</code> when the selectors says that the file should not be selected, <code>true</code>
+     *         otherwise.
      */
     protected boolean isSelected( String name, File file )
     {
@@ -576,12 +536,11 @@ public class DirectoryScanner
     }
 
     /**
-     * Returns the names of the files which matched at least one of the
-     * include patterns and none of the exclude patterns.
-     * The names are relative to the base directory.
+     * Returns the names of the files which matched at least one of the include patterns and none of the exclude
+     * patterns. The names are relative to the base directory.
      *
-     * @return the names of the files which matched at least one of the
-     *         include patterns and none of the exclude patterns.
+     * @return the names of the files which matched at least one of the include patterns and none of the exclude
+     *         patterns.
      */
     public String[] getIncludedFiles()
     {
@@ -591,12 +550,10 @@ public class DirectoryScanner
     }
 
     /**
-     * Returns the names of the files which matched none of the include
-     * patterns. The names are relative to the base directory. This involves
-     * performing a slow scan if one has not already been completed.
+     * Returns the names of the files which matched none of the include patterns. The names are relative to the base
+     * directory. This involves performing a slow scan if one has not already been completed.
      *
-     * @return the names of the files which matched none of the include
-     *         patterns.
+     * @return the names of the files which matched none of the include patterns.
      * @see #slowScan
      */
     public String[] getNotIncludedFiles()
@@ -608,13 +565,12 @@ public class DirectoryScanner
     }
 
     /**
-     * Returns the names of the files which matched at least one of the
-     * include patterns and at least one of the exclude patterns.
-     * The names are relative to the base directory. This involves
-     * performing a slow scan if one has not already been completed.
+     * Returns the names of the files which matched at least one of the include patterns and at least one of the exclude
+     * patterns. The names are relative to the base directory. This involves performing a slow scan if one has not
+     * already been completed.
      *
-     * @return the names of the files which matched at least one of the
-     *         include patterns and at at least one of the exclude patterns.
+     * @return the names of the files which matched at least one of the include patterns and at at least one of the
+     *         exclude patterns.
      * @see #slowScan
      */
     public String[] getExcludedFiles()
@@ -626,11 +582,10 @@ public class DirectoryScanner
     }
 
     /**
-     * <p>Returns the names of the files which were selected out and
-     * therefore not ultimately included.</p>
-     * <p/>
-     * <p>The names are relative to the base directory. This involves
-     * performing a slow scan if one has not already been completed.</p>
+     * <p>Returns the names of the files which were selected out and therefore not ultimately included.</p>
+     * 
+     * <p>The names are relative to the base directory. This involves performing a slow scan if one has not already been
+     * completed.</p>
      *
      * @return the names of the files which were deselected.
      * @see #slowScan
@@ -644,12 +599,11 @@ public class DirectoryScanner
     }
 
     /**
-     * Returns the names of the directories which matched at least one of the
-     * include patterns and none of the exclude patterns.
-     * The names are relative to the base directory.
+     * Returns the names of the directories which matched at least one of the include patterns and none of the exclude
+     * patterns. The names are relative to the base directory.
      *
-     * @return the names of the directories which matched at least one of the
-     *         include patterns and none of the exclude patterns.
+     * @return the names of the directories which matched at least one of the include patterns and none of the exclude
+     *         patterns.
      */
     public String[] getIncludedDirectories()
     {
@@ -659,12 +613,10 @@ public class DirectoryScanner
     }
 
     /**
-     * Returns the names of the directories which matched none of the include
-     * patterns. The names are relative to the base directory. This involves
-     * performing a slow scan if one has not already been completed.
+     * Returns the names of the directories which matched none of the include patterns. The names are relative to the
+     * base directory. This involves performing a slow scan if one has not already been completed.
      *
-     * @return the names of the directories which matched none of the include
-     *         patterns.
+     * @return the names of the directories which matched none of the include patterns.
      * @see #slowScan
      */
     public String[] getNotIncludedDirectories()
@@ -676,13 +628,12 @@ public class DirectoryScanner
     }
 
     /**
-     * Returns the names of the directories which matched at least one of the
-     * include patterns and at least one of the exclude patterns.
-     * The names are relative to the base directory. This involves
-     * performing a slow scan if one has not already been completed.
+     * Returns the names of the directories which matched at least one of the include patterns and at least one of the
+     * exclude patterns. The names are relative to the base directory. This involves performing a slow scan if one has
+     * not already been completed.
      *
-     * @return the names of the directories which matched at least one of the
-     *         include patterns and at least one of the exclude patterns.
+     * @return the names of the directories which matched at least one of the include patterns and at least one of the
+     *         exclude patterns.
      * @see #slowScan
      */
     public String[] getExcludedDirectories()
@@ -694,11 +645,10 @@ public class DirectoryScanner
     }
 
     /**
-     * <p>Returns the names of the directories which were selected out and
-     * therefore not ultimately included.</p>
-     * <p/>
-     * <p>The names are relative to the base directory. This involves
-     * performing a slow scan if one has not already been completed.</p>
+     * <p>Returns the names of the directories which were selected out and therefore not ultimately included.</p>
+     * 
+     * <p>The names are relative to the base directory. This involves performing a slow scan if one has not already been
+     * completed.</p>
      *
      * @return the names of the directories which were deselected.
      * @see #slowScan
@@ -712,14 +662,14 @@ public class DirectoryScanner
     }
 
     /**
-     * Checks whether a given file is a symbolic link.
-     * <p/>
-     * <p>It doesn't really test for symbolic links but whether the
-     * canonical and absolute paths of the file are identical - this
-     * may lead to false positives on some platforms.</p>
+     * <p>Checks whether a given file is a symbolic link.</p>
+     * 
+     * <p>It doesn't really test for symbolic links but whether the canonical and absolute paths of the file are identical
+     * - this may lead to false positives on some platforms.
+     * </p>
      *
      * @param parent the parent directory of the file to test
-     * @param name   the name of the file to test.
+     * @param name the name of the file to test.
      * @return true if it's a symbolic link
      * @throws java.io.IOException .
      * @since Ant 1.5
@@ -729,7 +679,7 @@ public class DirectoryScanner
     {
         if ( Java7Detector.isJava7() )
         {
-            return NioFiles.isSymbolicLink( parent );
+            return NioFiles.isSymbolicLink( new File( parent, name ) );
         }
         File resolvedParent = new File( parent.getCanonicalPath() );
         File toTest = new File( resolvedParent, name );
@@ -737,16 +687,13 @@ public class DirectoryScanner
     }
 
     /**
-     * Checks whether the parent of this file is a symbolic link.
-     * <p/>
-     *
-     * <p> For java versions prior to 7 It doesn't really test for
-     * symbolic links but whether the
-     * canonical and absolute paths of the file are identical - this
-     * may lead to false positives on some platforms.</p>
+     * <p>Checks whether the parent of this file is a symbolic link.</p>
+     * 
+     * <p>For java versions prior to 7 It doesn't really test for symbolic links but whether the canonical and absolute
+     * paths of the file are identical - this may lead to false positives on some platforms.</p>
      *
      * @param parent the parent directory of the file to test
-     * @param name   the name of the file to test.
+     * @param name the name of the file to test.
      * @return true if it's a symbolic link
      * @throws java.io.IOException .
      * @since Ant 1.5
