@@ -29,8 +29,7 @@ import java.util.List;
 import java.util.Map;
 
 /**
- * @version $Id$
- * NOTE: remove all the util code in here when separated, this class should be pure data.
+ * @version $Id$ NOTE: remove all the util code in here when separated, this class should be pure data.
  */
 public class Xpp3Dom
     implements Serializable
@@ -60,10 +59,9 @@ public class Xpp3Dom
     public static final String CHILDREN_COMBINATION_APPEND = "append";
 
     /**
-     * This default mode for combining children DOMs during merge means that where element names
-     * match, the process will try to merge the element data, rather than putting the dominant
-     * and recessive elements (which share the same element name) as siblings in the resulting
-     * DOM.
+     * This default mode for combining children DOMs during merge means that where element names match, the process will
+     * try to merge the element data, rather than putting the dominant and recessive elements (which share the same
+     * element name) as siblings in the resulting DOM.
      */
     public static final String DEFAULT_CHILDREN_COMBINATION_MODE = CHILDREN_COMBINATION_MERGE;
 
@@ -74,11 +72,10 @@ public class Xpp3Dom
     public static final String SELF_COMBINATION_MERGE = "merge";
 
     /**
-     * This default mode for combining a DOM node during merge means that where element names
-     * match, the process will try to merge the element attributes and values, rather than
-     * overriding the recessive element completely with the dominant one. This means that
-     * wherever the dominant element doesn't provide the value or a particular attribute, that
-     * value or attribute will be set from the recessive DOM node.
+     * This default mode for combining a DOM node during merge means that where element names match, the process will
+     * try to merge the element attributes and values, rather than overriding the recessive element completely with the
+     * dominant one. This means that wherever the dominant element doesn't provide the value or a particular attribute,
+     * that value or attribute will be set from the recessive DOM node.
      */
     public static final String DEFAULT_SELF_COMBINATION_MODE = SELF_COMBINATION_MERGE;
 
@@ -169,15 +166,18 @@ public class Xpp3Dom
 
     /**
      * Set the attribute value
+     * 
      * @param name String not null
      * @param value String not null
      */
     public void setAttribute( String name, String value )
     {
-        if ( null == value ) {
+        if ( null == value )
+        {
             throw new NullPointerException( "Attribute value can not be null" );
         }
-        if ( null == name ) {
+        if ( null == name )
+        {
             throw new NullPointerException( "Attribute name can not be null" );
         }
         if ( null == attributes )
@@ -285,7 +285,8 @@ public class Xpp3Dom
     public void writeToSerializer( String namespace, XmlSerializer serializer )
         throws IOException
     {
-        // TODO: WARNING! Later versions of plexus-utils psit out an <?xml ?> header due to thinking this is a new document - not the desired behaviour!
+        // TODO: WARNING! Later versions of plexus-utils psit out an <?xml ?> header due to thinking this is a new
+        // document - not the desired behaviour!
         SerializerXMLWriter xmlWriter = new SerializerXMLWriter( namespace, serializer );
         Xpp3DomWriter.write( xmlWriter, this );
         if ( xmlWriter.getExceptions().size() > 0 )
@@ -295,44 +296,23 @@ public class Xpp3Dom
     }
 
     /**
-     * Merges one DOM into another, given a specific algorithm and possible override points for that algorithm.
-     * The algorithm is as follows:
-     *
-     * 1. if the recessive DOM is null, there is nothing to do...return.
-     *
-     * 2. Determine whether the dominant node will suppress the recessive one (flag=mergeSelf).
-     *
-     *    A. retrieve the 'combine.self' attribute on the dominant node, and try to match against 'override'...
-     *       if it matches 'override', then set mergeSelf == false...the dominant node suppresses the recessive
-     *       one completely.
-     *
-     *    B. otherwise, use the default value for mergeSelf, which is true...this is the same as specifying
-     *       'combine.self' == 'merge' as an attribute of the dominant root node.
-     *
-     * 3. If mergeSelf == true
-     *
-     *    A. if the dominant root node's value is empty, set it to the recessive root node's value
-     *
-     *    B. For each attribute in the recessive root node which is not set in the dominant root node, set it.
-     *
-     *    C. Determine whether children from the recessive DOM will be merged or appended to the dominant
-     *       DOM as siblings (flag=mergeChildren).
-     *
-     *       i.   if childMergeOverride is set (non-null), use that value (true/false)
-     *
-     *       ii.  retrieve the 'combine.children' attribute on the dominant node, and try to match against
-     *            'append'...if it matches 'append', then set mergeChildren == false...the recessive children
-     *            will be appended as siblings of the dominant children.
-     *
-     *       iii. otherwise, use the default value for mergeChildren, which is true...this is the same as
-     *            specifying 'combine.children' == 'merge' as an attribute on the dominant root node.
-     *
-     *    D. Iterate through the recessive children, and:
-     *
-     *       i.   if mergeChildren == true and there is a corresponding dominant child (matched by element name),
-     *            merge the two.
-     *
-     *       ii.  otherwise, add the recessive child as a new child on the dominant root node.
+     * Merges one DOM into another, given a specific algorithm and possible override points for that algorithm. The
+     * algorithm is as follows: 1. if the recessive DOM is null, there is nothing to do...return. 2. Determine whether
+     * the dominant node will suppress the recessive one (flag=mergeSelf). A. retrieve the 'combine.self' attribute on
+     * the dominant node, and try to match against 'override'... if it matches 'override', then set mergeSelf ==
+     * false...the dominant node suppresses the recessive one completely. B. otherwise, use the default value for
+     * mergeSelf, which is true...this is the same as specifying 'combine.self' == 'merge' as an attribute of the
+     * dominant root node. 3. If mergeSelf == true A. if the dominant root node's value is empty, set it to the
+     * recessive root node's value B. For each attribute in the recessive root node which is not set in the dominant
+     * root node, set it. C. Determine whether children from the recessive DOM will be merged or appended to the
+     * dominant DOM as siblings (flag=mergeChildren). i. if childMergeOverride is set (non-null), use that value
+     * (true/false) ii. retrieve the 'combine.children' attribute on the dominant node, and try to match against
+     * 'append'...if it matches 'append', then set mergeChildren == false...the recessive children will be appended as
+     * siblings of the dominant children. iii. otherwise, use the default value for mergeChildren, which is true...this
+     * is the same as specifying 'combine.children' == 'merge' as an attribute on the dominant root node. D. Iterate
+     * through the recessive children, and: i. if mergeChildren == true and there is a corresponding dominant child
+     * (matched by element name), merge the two. ii. otherwise, add the recessive child as a new child on the dominant
+     * root node.
      */
     private static void mergeIntoXpp3Dom( Xpp3Dom dominant, Xpp3Dom recessive, Boolean childMergeOverride )
     {
@@ -440,11 +420,10 @@ public class Xpp3Dom
      *
      * @see #CHILDREN_COMBINATION_MODE_ATTRIBUTE
      * @see #SELF_COMBINATION_MODE_ATTRIBUTE
-     *
      * @param dominant The dominant DOM into which the recessive value/attributes/children will be merged
      * @param recessive The recessive DOM, which will be merged into the dominant DOM
-     * @param childMergeOverride Overrides attribute flags to force merging or appending of child elements
-     *        into the dominant DOM
+     * @param childMergeOverride Overrides attribute flags to force merging or appending of child elements into the
+     *            dominant DOM
      */
     public static Xpp3Dom mergeXpp3Dom( Xpp3Dom dominant, Xpp3Dom recessive, Boolean childMergeOverride )
     {
@@ -457,13 +436,11 @@ public class Xpp3Dom
     }
 
     /**
-     * Merge two DOMs, with one having dominance in the case of collision.
-     * Merge mechanisms (vs. override for nodes, or vs. append for children) is determined by
-     * attributes of the dominant root node.
+     * Merge two DOMs, with one having dominance in the case of collision. Merge mechanisms (vs. override for nodes, or
+     * vs. append for children) is determined by attributes of the dominant root node.
      *
      * @see #CHILDREN_COMBINATION_MODE_ATTRIBUTE
      * @see #SELF_COMBINATION_MODE_ATTRIBUTE
-     *
      * @param dominant The dominant DOM into which the recessive value/attributes/children will be merged
      * @param recessive The recessive DOM, which will be merged into the dominant DOM
      */
@@ -529,7 +506,8 @@ public class Xpp3Dom
 
     public String toString()
     {
-        // TODO: WARNING! Later versions of plexus-utils psit out an <?xml ?> header due to thinking this is a new document - not the desired behaviour!
+        // TODO: WARNING! Later versions of plexus-utils psit out an <?xml ?> header due to thinking this is a new
+        // document - not the desired behaviour!
         StringWriter writer = new StringWriter();
         XMLWriter xmlWriter = new PrettyPrintXMLWriter( writer, "UTF-8", null );
         Xpp3DomWriter.write( xmlWriter, this );
@@ -538,7 +516,8 @@ public class Xpp3Dom
 
     public String toUnescapedString()
     {
-        // TODO: WARNING! Later versions of plexus-utils psit out an <?xml ?> header due to thinking this is a new document - not the desired behaviour!
+        // TODO: WARNING! Later versions of plexus-utils psit out an <?xml ?> header due to thinking this is a new
+        // document - not the desired behaviour!
         StringWriter writer = new StringWriter();
         XMLWriter xmlWriter = new PrettyPrintXMLWriter( writer, "UTF-8", null );
         Xpp3DomWriter.write( xmlWriter, this, false );
